@@ -5,6 +5,7 @@ import os
 import asyncio
 import json
 import requests
+import urllib.parse
 
 from pymem import pymem
 #import logging
@@ -32,9 +33,8 @@ class KH2Context(CommonContext):
     game = "Kingdom Hearts 2"
     items_handling = 0b111  # Indicates you get items sent from other worlds.
 
-    def __init__(self, server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+    def __init__(self, server_address: str = None, password: str = None, ready_callback=None, error_callback=None):
         super(KH2Context, self).__init__(server_address = server_address, password = password)
-        self.slot_name = slot_name
         self.ready_callback = ready_callback
         self.error_callback = error_callback
         self.goofy_ability_to_slot = dict()
@@ -60,10 +60,7 @@ class KH2Context(CommonContext):
             for k, v in dic.items()}
         self.location_name_to_worlddata = {name: data for name, data, in all_world_locations.items()}
 
-        if self.slot_name is not None:
-            self.auth = self.slot_name
-        else:
-            self.auth = None
+        self.username = urllib.parse.urlparse(server_address).username
 
         self.disconnect_from_server = False
         self.pause_game = False
@@ -307,10 +304,10 @@ class KH2Context(CommonContext):
         # and seed name is none or saved seed name
         if not self.kh2seedname:
             await self.send_connect()
-        elif self.slot_name == self.auth and self.kh2seedname:
+        elif self.username == self.auth and self.kh2seedname:
             await self.send_connect()
         else:
-            logger.info(f"You are trying to connect with data still cached in the client. Close client or connect to the correct slot: {self.slot_name}")
+            logger.info(f"You are trying to connect with data still cached in the client. Close client or connect to the correct slot: {self.username}")
             self.serverconnected = False
             self.disconnect_from_server = True
 
@@ -591,7 +588,6 @@ class KH2Context(CommonContext):
                 self.kh2connected = False
             logger.info("Game is not open. If it is open run the launcher/client as admin.")
         self.serverconnected = True
-        self.slot_name = self.auth
 
     def data_package_kh2_cache(self, loc_to_id, item_to_id):
         self.kh2_loc_name_to_id = loc_to_id
@@ -718,9 +714,6 @@ class KH2Context(CommonContext):
 async def kh2_watcher(ctx: KH2Context):
     while not ctx.exit_event.is_set():
         try:
-            if ctx.pause_game:
-                await asyncio.sleep(5)
-                continue
             if ctx.kh2connected and ctx.serverconnected:
                 ctx.sending = []
                 await asyncio.create_task(ctx.checkWorldLocations())
@@ -773,7 +766,7 @@ async def kh2_watcher(ctx: KH2Context):
                             # Still waiting for memory to be readable, retry after short delay
                             await asyncio.sleep(0.5)
                     except Exception as e:
-                        logger.info("Game not found, retrying in 5 seconds...")
+                        # Retry search for game silently
                         if not ctx.exit_event.is_set():
                             await asyncio.sleep(5)
             if ctx.disconnect_from_server:
@@ -783,18 +776,16 @@ async def kh2_watcher(ctx: KH2Context):
             if ctx.kh2connected:
                 ctx.kh2connected = False
                 logger.info("Game connection lost, will attempt to reconnect.")
-            if "Could not find process" in str(e):
-                logger.info("Game process not found, retrying in 5 seconds...")
             else:
-                logger.info(f"Watcher error: {str(e)}")
+                logger.debug(f"Watcher error: {str(e)}")
         await asyncio.sleep(0.5)
 
 
-def launch(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+def launch(server_address: str = None, password: str = None, ready_callback=None, error_callback=None):
     Utils.init_logging("KH2Client")
 
     async def main(args):
-        ctx = KH2Context(server_address, slot_name, password, ready_callback, error_callback)
+        ctx = KH2Context(server_address, password, ready_callback, error_callback)
         if ctx._can_takeover_existing_gui():
             await ctx._takeover_existing_gui() 
         else:
@@ -823,12 +814,11 @@ def launch(server_address: str = None, slot_name: str = None, password: str = No
         
         # Create a simple namespace object to mimic argparse.Namespace
         class Args:
-            def __init__(self, server_address, slot_name, password):
+            def __init__(self, server_address, password):
                 self.server_address = server_address
-                self.slot_name = slot_name
                 self.password = password
         
-        args = Args(server_address, slot_name, password)
+        args = Args(server_address, password)
         task = asyncio.create_task(main(args), name="KH2Main")
         return task
     except RuntimeError:
@@ -836,6 +826,6 @@ def launch(server_address: str = None, slot_name: str = None, password: str = No
         if error_callback:
             error_callback()
 
-def main(server_address: str, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+def main(server_address: str, password: str = None, ready_callback=None, error_callback=None):
     """Main entry point for integration with MultiWorld system"""
-    launch(server_address, slot_name, password, ready_callback, error_callback)
+    launch(server_address, password, ready_callback, error_callback)
