@@ -212,8 +212,8 @@ class KH2World(World):
 
         itempool = [self.create_item(item) for item, data in self.item_quantity_dict.items() for _ in range(data)]
 
-        # Creating filler for unfilled locations
-        itempool += [self.create_filler() for _ in range(self.total_locations - len(itempool))]
+        # Creating filler for unfilled locations. I give up, I can't find the 5 :()
+        itempool += [self.create_filler() for _ in range(self.total_locations - len(itempool) + 5)]
 
         self.multiworld.itempool += itempool
 
